wgpu_device_create_buffer_mapped

Function wgpu_device_create_buffer_mapped 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wgpu_device_create_buffer_mapped( device_id: DeviceId, desc: &BufferDescriptor, mapped_ptr_out: *mut *mut u8, ) -> BufferId
Safety

This function is unsafe as there is no guarantee that the given pointer dereferenced in this function is valid.