wgpu_queue_submit

Function wgpu_queue_submit 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wgpu_queue_submit( queue_id: QueueId, command_buffers: *const CommandBufferId, command_buffers_length: usize, )
Safety

This function is unsafe as there is no guarantee that the given pointer is valid for command_buffers_length elements.