wgpu_render_pass_end_pass

Function wgpu_render_pass_end_pass 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wgpu_render_pass_end_pass( pass_id: RenderPassId, )
Safety

This function is unsafe because improper use may lead to memory problems. For example, a double-free may occur if the function is called twice on the same raw pointer.