wgpu_render_pass_set_bind_group

Function wgpu_render_pass_set_bind_group 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wgpu_render_pass_set_bind_group( pass: &mut RawPass, index: u32, bind_group_id: Id<BindGroup<Backend>>, offsets: *const u32, offset_length: usize, )
Safety

This function is unsafe as there is no guarantee that the given pointer is valid for offset_length elements.